==> choqok_1.5.orig.tar.xz: choqok-1.5/microblogs/twitter/twittercomposerwidget.h <==
/*
    This file is part of Choqok, the KDE micro-blogging client

    Copyright (C) 2008-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/

*/

#ifndef LACONICACOMPOSERWIDGET_H
#define LACONICACOMPOSERWIDGET_H

#include <twitterapihelper/twitterapicomposerwidget.h>


class TwitterComposerWidget : public TwitterApiComposerWidget
{
    Q_OBJECT
public:
    explicit TwitterComposerWidget(Choqok::Account* account, QWidget* parent = 0);
    ~TwitterComposerWidget();

protected slots:
    virtual void submitPost(const QString& text);
    virtual void slotPostMediaSubmitted(Choqok::Account *theAccount, Choqok::Post* post);
//     virtual void slotErrorPost(Choqok::Account* theAccount,Choqok::Post* post);
    virtual void selectMediumToAttach();
    virtual void cancelAttachMedium();

private:
    class Private;
    Private *d;
};

#endif // LACONICACOMPOSERWIDGET_H

==> choqok_1.7.0.orig.tar.xz: choqok-1.7.0/microblogs/twitter/twittercomposerwidget.h <==
/*
    This file is part of Choqok, the KDE micro-blogging client

    Copyright (C) 2008-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/

*/

#ifndef TWITTERCOMPOSERWIDGET_H
#define TWITTERCOMPOSERWIDGET_H

#include "twitterapicomposerwidget.h"

class TwitterComposerWidget : public TwitterApiComposerWidget
{
    Q_OBJECT
public:
    explicit TwitterComposerWidget(Choqok::Account *account, QWidget *parent = nullptr);
    ~TwitterComposerWidget();

protected Q_SLOTS:
    virtual void submitPost(const QString &text) override;
    void slotPostMediaSubmitted(Choqok::Account *theAccount, Choqok::Post *post);
    void selectMediumToAttach();
    void cancelAttachMedium();

private:
    class Private;
    Private *d;
};

#endif // TWITTERCOMPOSERWIDGET_H
